A library to fetch data about ETFs active on Tehran Stock Exchange.
The `sites` module provides functions to retrieve info from fund websites directly.
There a module named `ravest` to fetch data from https://ravest.ir .
